import * as pretty_format from 'pretty-format';
import { T as TestFactory, S as SuiteCollector, a as TestFunction, b as SuiteHooks, U as UserOptions } from './types-4b0e87eb';
export { C as ComputeMode, F as File, G as GlobalContext, H as HookListener, l as Reporter, R as ResolvedConfig, c as RunMode, k as RunnerContext, g as Suite, S as SuiteCollector, b as SuiteHooks, i as Task, e as TaskBase, f as TaskResult, h as Test, j as TestCollector, T as TestFactory, a as TestFunction, d as TestState, U as UserOptions } from './types-4b0e87eb';
export { assert, default as chai, expect, should } from 'chai';
import sinon from 'sinon';
export { default as sinon } from 'sinon';
import '@antfu/utils';
import 'jest-snapshot';
import 'jest-snapshot/build/State';

declare const suite: {
    (suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
    concurrent: {
        (suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
        skip(suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
        only(suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
        todo(suiteName: string): SuiteCollector;
    };
    skip: {
        (suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
        concurrent: (suiteName: string, factory?: TestFactory | undefined) => SuiteCollector;
    };
    only: {
        (suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
        concurrent: (suiteName: string, factory?: TestFactory | undefined) => SuiteCollector;
    };
    todo: {
        (suiteName: string): SuiteCollector;
        concurrent: (suiteName: string) => SuiteCollector;
    };
};
declare const defaultSuite: SuiteCollector;
declare function createSuiteHooks(): {
    beforeAll: never[];
    afterAll: never[];
    beforeEach: never[];
    afterEach: never[];
};
declare const test: {
    (name: string, fn: TestFunction): void;
    concurrent: {
        (name: string, fn: TestFunction): void;
        skip(name: string, fn: TestFunction): void;
        only(name: string, fn: TestFunction): void;
        todo(name: string): void;
    };
    skip: {
        (name: string, fn: TestFunction): void;
        concurrent(name: string, fn: TestFunction): void;
    };
    only: {
        (name: string, fn: TestFunction): void;
        concurrent(name: string, fn: TestFunction): void;
    };
    todo: {
        (name: string): void;
        concurrent(name: string): void;
    };
};
declare const describe: {
    (suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
    concurrent: {
        (suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
        skip(suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
        only(suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
        todo(suiteName: string): SuiteCollector;
    };
    skip: {
        (suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
        concurrent: (suiteName: string, factory?: TestFactory | undefined) => SuiteCollector;
    };
    only: {
        (suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
        concurrent: (suiteName: string, factory?: TestFactory | undefined) => SuiteCollector;
    };
    todo: {
        (suiteName: string): SuiteCollector;
        concurrent: (suiteName: string) => SuiteCollector;
    };
};
declare const it: {
    (name: string, fn: TestFunction): void;
    concurrent: {
        (name: string, fn: TestFunction): void;
        skip(name: string, fn: TestFunction): void;
        only(name: string, fn: TestFunction): void;
        todo(name: string): void;
    };
    skip: {
        (name: string, fn: TestFunction): void;
        concurrent(name: string, fn: TestFunction): void;
    };
    only: {
        (name: string, fn: TestFunction): void;
        concurrent(name: string, fn: TestFunction): void;
    };
    todo: {
        (name: string): void;
        concurrent(name: string): void;
    };
};
declare const beforeAll: (fn: SuiteHooks['beforeAll'][0]) => void;
declare const afterAll: (fn: SuiteHooks['afterAll'][0]) => void;
declare const beforeEach: (fn: SuiteHooks['beforeEach'][0]) => void;
declare const afterEach: (fn: SuiteHooks['afterEach'][0]) => void;
declare function clearContext(): void;

declare const mock: sinon.SinonMockStatic;
declare const spy: sinon.SinonSpyStatic;
declare const stub: sinon.SinonStubStatic;

declare module 'vite' {
    interface UserConfig {
        /**
         * Options for Vitest
         */
        test?: UserOptions;
    }
}
declare global {
    namespace Chai {
        interface Assertion {
            toMatchSnapshot(message?: string): Assertion;
            matchSnapshot(message?: string): Assertion;
            toEqual(expected: any): void;
            toStrictEqual(expected: any): void;
            toBe(expected: any): void;
            toMatch(expected: string | RegExp): void;
            toMatchObject(expected: any): void;
            toContain(item: any): void;
            toBeTruthy(): void;
            toBeFalsy(): void;
            toBeNaN(): void;
            toBeUndefined(): void;
            toBeNull(): void;
            toBeDefined(): void;
            toBeInstanceOf(c: any): void;
            toHaveBeenCalledTimes(n: number): void;
            toHaveBeenCalledOnce(): void;
            toHaveBeenCalled(): void;
            toHaveBeenCalledWith(...args: any[]): void;
        }
        interface ExpectStatic {
            addSnapshotSerializer: pretty_format.Plugin;
        }
    }
}

export { afterAll, afterEach, beforeAll, beforeEach, clearContext, createSuiteHooks, defaultSuite, describe, it, mock, spy, stub, suite, test };
